#' Add a new report in a fairify project
#'
#' @param name Name of the report (sub-folder name in "reports")
#' @param template The report template chosen between the folders located in
#' the "templates" folder of the fairify project
#' @param path Path of the fairify project
#'
#' @return The path of the added report
#' @export
#'
#' @inherit create_reports examples
#'
add_report <- function(name, template = "inrae", path = ".") {
  if (!dir.exists(file.path(path, "reports"))) {
    stop("Report structure not found, call `create_reports` first!")
  }
  destpath <- file.path(path, "reports", name)
  if (dir.exists(destpath))
    stop("The folder ",
         destpath,
         " exists already. Delete it first or choose another.")
  dirtmp <- tempfile()
  dir.create(dirtmp, recursive = TRUE)
  b <- file.copy(
    from = file.path(pkg_sys("bookdown_template")),
    to = dirtmp,
    recursive = TRUE,
    copy.date = TRUE
  )
  if (any(!b)) stop("The creation of the report failed")
  file.rename(
    file.path(dirtmp, "bookdown_template"),
    destpath
  )

  lapply(c("in_header", "before_body", "after_body"), function(x) {
    tex_content <- c(sprintf("\\input{../../templates/%s/%s}", template, x),
                 "\n",
                 "% Add your own settings below to append or overwrite template settings")
    writeLines(tex_content, file.path(destpath, sprintf("%s.tex", x)))
  })

  return(destpath)
}
